polyfemos.almanac.utils — polyfemos 0.3.29 documentation

# polyfemos.almanac.utils

Collection of miscellanous date functions

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.almanac.utils.` `get_jY`(date_)
  Parameters

    date_ (`date` or `UTCDateTime`.) –

  Return type

    int, int

  Returns

    the day of the year and the year of given `date_`

`polyfemos.almanac.utils.` `parse_date`(datestr)

  If empty `datestr` is give, today is returned

  Parameters

    datestr (str or `date` or `UTCDateTime`) – date in format ‘YEAR-MONTH-DAY’ or ‘YEAR-JULDAY’

  Return type

    `UTCDateTime`

  Returns